LiquidTokenType

Enum LiquidTokenType 

pub enum LiquidTokenType {
Show 37 variants Text, DoubleLeftBrace, DoubleRightBrace, LeftBracePercent, PercentRightBrace, Identifier, String, Number, Boolean, LeftBrace, RightBrace, LeftParen, RightParen, LeftBracket, RightBracket, Comma, Dot, Colon, Semicolon, Pipe, Eq, Plus, Minus, Star, Slash, Percent, Bang, Question, Lt, Gt, Amp, Caret, Tilde, Whitespace, Comment, Eof, Error,
}
Token types for Liquid templates

Variants



Text

Text content



DoubleLeftBrace

Opening delimiter: {{



DoubleRightBrace

Closing delimiter: }}



LeftBracePercent

Opening block delimiter: {%



PercentRightBrace

Closing block delimiter: %}



Identifier

Identifier



String

String literal



Number

Number literal



Boolean

Boolean literal



LeftBrace

Left brace: {



RightBrace

Right brace: }



LeftParen

Left parenthesis: (



RightParen

Right parenthesis: )



LeftBracket

Left bracket: [



RightBracket

Right bracket: ]



Comma

Comma: ,



Dot

Dot: .



Colon

Colon: :



Semicolon

Semicolon: ;



Pipe

Pipe: |



Eq

Equals: =



Plus

Plus: +



Minus

Minus: -



Star

Star: *



Slash

Slash: /



Percent

Percent: %



Bang

Bang: !



Question

Question: ?



Lt

Less than: <



Gt

Greater than: >



Amp

Ampersand: &



Caret

Caret: ^



Tilde

Tilde: ~



Whitespace

Whitespace



Comment

Comment



Eof

End of file



Error

Error